middleware

package
v0.0.0-...-05e4c81 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2019 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const DeviceIdCookie = "DeviceID"
const RequestIdHeader = "X-Request-ID"

Variables

This section is empty.

Functions

func Logger

func Logger() martini.Handler

Logger returns a middleware handler that logs the request as it goes in and the response as it goes out.

func Metadata

func Metadata() martini.Handler

Types

type DeviceID

type DeviceID string

type RequestID

type RequestID string

Directories

Path Synopsis

Jump to