Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExtAuthCredentials ¶
type ExtAuthCredentials struct {
Code string `json:"code"`
}
type MemberInfo ¶
type MemberInfo struct {
ID string `json:"id" bson:"_id"`
RoomID string `json:"room" bson:"room"`
MemberID string `json:"member" bson:"member"`
JoinedAt Timestamp `json:"joinedAt" bson:"joinedAt"` // marker to start reading messages from
LastReadAt Timestamp `json:"lastReadAt" bson:"lastReadAt"` // marker to notify about the new messages
}
Structure describes particular room membership I.e. if user exits private chat the second participant still can see the chat log and current member while current user don't see the chat until its participant starts writing into it by initiating new conversation fur the current user
type Message ¶
type Message struct {
ID string `json:"id" bson:"_id"`
RoomID string `json:"room" bson:"room"`
FromID string `json:"from" bson:"from"`
Timestamp Timestamp `json:"timestamp" bson:"timestamp"`
Type string `json:"type" bson:"-"`
Body string `json:"body" bson:"body"`
Reactions map[string]string `json:"reactions,omitempty" bson:"reactions,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.